=============
Osprey Design
=============


.. image:: https://img.shields.io/pypi/v/osprey_design.svg
        :target: https://pypi.python.org/pypi/osprey_design

.. image:: https://img.shields.io/travis/gusennan/osprey_design.svg
        :target: https://travis-ci.org/gusennan/osprey_design

.. image:: https://readthedocs.org/projects/osprey-design/badge/?version=latest
        :target: https://osprey-design.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/gusennan/osprey_design/shield.svg
     :target: https://pyup.io/repos/github/gusennan/osprey_design/
     :alt: Updates



Provides a workflow to help you create reproducable OSPREY designs


* Free software: GNU General Public License v3
* Documentation: https://osprey-design.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `elgertam/cookiecutter-pipenv`_ project template, based on `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`elgertam/cookiecutter-pipenv`: https://github.com/elgertam/cookiecutter-pipenv
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
